@@ -1,10 +1,8 @@
 import asyncio
-import httpx
 import time
 
 import zeep
 
-from zeep.transports import AsyncTransport
 
 
 def run_async():
