@@ -1,4 +1,4 @@
-from six import StringIO
+from io import StringIO
 
 from tests.utils import assert_nodes_equal, load_xml
 from zeep.wsdl import wsdl
