@@ -1,5 +1,4 @@
 import datetime
-import io
 
 from lxml import etree
 
@@ -437,9 +436,7 @@ def test_issue_221():
     transport.bind(
         "https://www.w3.org/TR/xmldsig-core/xmldsig-core-schema.xsd",
         load_xml(
-            io.open("tests/wsdl_files/xmldsig-core-schema.xsd", "r")
-            .read()
-            .encode("utf-8")
+            open("tests/wsdl_files/xmldsig-core-schema.xsd").read().encode("utf-8")
         ),
     )
 
