@@ -7,42 +7,44 @@ from zeep.xsd.schema import Schema
 
 
 def parse_schema_node(node):
-    schema = Schema(
-        node=node,
-        transport=None,
-        location=None)
+    schema = Schema(node=node, transport=None, location=None)
     return schema
 
 
 def test_schema_empty():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
               targetNamespace="http://tests.python-zeep.org/"
               elementFormDefault="qualified"
               attributeFormDefault="unqualified">
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    root = schema._get_schema_documents('http://tests.python-zeep.org/')[0]
-    assert root._element_form == 'qualified'
-    assert root._attribute_form == 'unqualified'
+    root = schema._get_schema_documents("http://tests.python-zeep.org/")[0]
+    assert root._element_form == "qualified"
+    assert root._attribute_form == "unqualified"
 
 
 def test_element_simle_types():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
               targetNamespace="http://tests.python-zeep.org/">
             <element name="foo" type="string" />
             <element name="bar" type="int" />
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    assert schema.get_element('{http://tests.python-zeep.org/}foo')
-    assert schema.get_element('{http://tests.python-zeep.org/}bar')
+    assert schema.get_element("{http://tests.python-zeep.org/}foo")
+    assert schema.get_element("{http://tests.python-zeep.org/}bar")
 
 
 def test_element_simple_type_annotation():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
               targetNamespace="http://tests.python-zeep.org/">
             <element name="foo" type="string">
@@ -51,27 +53,31 @@ def test_element_simple_type_annotation():
                 </annotation>
             </element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    element = schema.get_element('{http://tests.python-zeep.org/}foo')
+    element = schema.get_element("{http://tests.python-zeep.org/}foo")
     assert element
 
 
 def test_element_default_type():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
                 targetNamespace="http://tests.python-zeep.org/">
             <element name="foo" />
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    element = schema.get_element('{http://tests.python-zeep.org/}foo')
+    element = schema.get_element("{http://tests.python-zeep.org/}foo")
     assert isinstance(element.type, xsd.AnyType)
 
 
 def test_element_simple_type_unresolved():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
                 targetNamespace="http://tests.python-zeep.org/">
@@ -87,13 +93,15 @@ def test_element_simple_type_unresolved():
                 </restriction>
             </simpleType>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    assert schema.get_type('{http://tests.python-zeep.org/}unresolved')
+    assert schema.get_type("{http://tests.python-zeep.org/}unresolved")
 
 
 def test_element_max_occurs():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
               targetNamespace="http://tests.python-zeep.org/">
             <element name="container">
@@ -107,23 +115,25 @@ def test_element_max_occurs():
                 </complexType>
             </element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    elm = schema.get_element('{http://tests.python-zeep.org/}container')
+    elm = schema.get_element("{http://tests.python-zeep.org/}container")
     elements = dict(elm.type.elements)
 
-    assert isinstance(elements['e1'], xsd.Element)
-    assert elements['e1'].max_occurs == 1
-    assert isinstance(elements['e2'], xsd.Element)
-    assert elements['e2'].max_occurs == 1
-    assert isinstance(elements['e3'], xsd.Element)
-    assert elements['e3'].max_occurs == 2
-    assert isinstance(elements['e4'], xsd.Element)
-    assert elements['e4'].max_occurs == 'unbounded'
+    assert isinstance(elements["e1"], xsd.Element)
+    assert elements["e1"].max_occurs == 1
+    assert isinstance(elements["e2"], xsd.Element)
+    assert elements["e2"].max_occurs == 1
+    assert isinstance(elements["e3"], xsd.Element)
+    assert elements["e3"].max_occurs == 2
+    assert isinstance(elements["e4"], xsd.Element)
+    assert elements["e4"].max_occurs == "unbounded"
 
 
 def test_simple_content():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 targetNamespace="http://tests.python-zeep.org/">
@@ -135,14 +145,16 @@ def test_simple_content():
                 </simpleContent>
             </complexType>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_type = schema.get_type('{http://tests.python-zeep.org/}container')
-    assert xsd_type(10, sizing='qwe')
+    xsd_type = schema.get_type("{http://tests.python-zeep.org/}container")
+    assert xsd_type(10, sizing="qwe")
 
 
 def test_attribute_optional():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 targetNamespace="http://tests.python-zeep.org/">
@@ -152,9 +164,10 @@ def test_attribute_optional():
             </complexType>
           </element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}foo')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
     value = xsd_element()
 
     node = render_node(xsd_element, value)
@@ -167,7 +180,8 @@ def test_attribute_optional():
 
 
 def test_attribute_required():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 targetNamespace="http://tests.python-zeep.org/">
@@ -177,15 +191,16 @@ def test_attribute_required():
             </complexType>
           </element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}foo')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
     value = xsd_element()
 
     with pytest.raises(exceptions.ValidationError):
         node = render_node(xsd_element, value)
 
-    value.base = 'foo'
+    value.base = "foo"
     node = render_node(xsd_element, value)
 
     expected = """
@@ -197,7 +212,8 @@ def test_attribute_required():
 
 
 def test_attribute_default():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 targetNamespace="http://tests.python-zeep.org/">
@@ -207,9 +223,10 @@ def test_attribute_default():
             </complexType>
           </element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}foo')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
     value = xsd_element()
 
     node = render_node(xsd_element, value)
@@ -222,7 +239,8 @@ def test_attribute_default():
 
 
 def test_attribute_simple_type():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 targetNamespace="http://tests.python-zeep.org/">
@@ -239,14 +257,16 @@ def test_attribute_simple_type():
             </complexType>
           </element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}foo')
-    assert xsd_element(bar='hoi')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
+    assert xsd_element(bar="hoi")
 
 
 def test_attribute_any_type():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 targetNamespace="http://tests.python-zeep.org/">
@@ -256,10 +276,11 @@ def test_attribute_any_type():
             </complexType>
           </element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}foo')
-    value = xsd_element(base='hoi')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
+    value = xsd_element(base="hoi")
 
     node = render_node(xsd_element, value)
     expected = """
@@ -271,7 +292,8 @@ def test_attribute_any_type():
 
 
 def test_complex_content_mixed():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -286,12 +308,13 @@ def test_complex_content_mixed():
             </xsd:complexType>
           </xsd:element>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}foo')
-    result = xsd_element('basetype', bar='hoi')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
+    result = xsd_element("basetype", bar="hoi")
 
-    node = etree.Element('document')
+    node = etree.Element("document")
     xsd_element.render(node, result)
 
     expected = """
@@ -303,7 +326,8 @@ def test_complex_content_mixed():
 
 
 def test_complex_content_extension():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema
                 xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -334,21 +358,22 @@ def test_complex_content_extension():
           </complexType>
           <element name="test" type="tns:BaseType"/>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
 
-    record_type = schema.get_type('{http://tests.python-zeep.org/}SubType1')
+    record_type = schema.get_type("{http://tests.python-zeep.org/}SubType1")
     assert len(record_type.attributes) == 2
     assert len(record_type.elements) == 1
 
-    record_type = schema.get_type('{http://tests.python-zeep.org/}SubType2')
+    record_type = schema.get_type("{http://tests.python-zeep.org/}SubType2")
     assert len(record_type.attributes) == 3
     assert len(record_type.elements) == 1
 
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}test')
-    xsd_type = schema.get_type('{http://tests.python-zeep.org/}SubType2')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}test")
+    xsd_type = schema.get_type("{http://tests.python-zeep.org/}SubType2")
 
-    value = xsd_type(attr_a='a', attr_b='b', attr_c='c')
+    value = xsd_type(attr_a="a", attr_b="b", attr_c="c")
     node = render_node(xsd_element, value)
     expected = """
       <document>
@@ -362,7 +387,8 @@ def test_complex_content_extension():
 
 
 def test_simple_content_extension():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema
                 xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -393,20 +419,22 @@ def test_simple_content_extension():
             </simpleContent>
           </complexType>
         </schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
 
-    record_type = schema.get_type('{http://tests.python-zeep.org/}SubType1')
+    record_type = schema.get_type("{http://tests.python-zeep.org/}SubType1")
     assert len(record_type.attributes) == 2
     assert len(record_type.elements) == 1
 
-    record_type = schema.get_type('{http://tests.python-zeep.org/}SubType2')
+    record_type = schema.get_type("{http://tests.python-zeep.org/}SubType2")
     assert len(record_type.attributes) == 3
     assert len(record_type.elements) == 1
 
 
 def test_list_type():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -424,11 +452,11 @@ def test_list_type():
             </xsd:complexType>
           </xsd:element>
         </schema>
-    """)
+    """
+    )
 
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element(
-        '{http://tests.python-zeep.org/}foo')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
     value = xsd_element(arg=[1, 2, 3, 4, 5])
 
     node = render_node(xsd_element, value)
@@ -443,7 +471,8 @@ def test_list_type():
 
 
 def test_list_type_unresolved():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -465,11 +494,11 @@ def test_list_type_unresolved():
             </xsd:complexType>
           </xsd:element>
         </schema>
-    """)
+    """
+    )
 
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element(
-        '{http://tests.python-zeep.org/}foo')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
     value = xsd_element(arg=[1, 2, 3, 4, 5])
 
     node = render_node(xsd_element, value)
@@ -484,7 +513,8 @@ def test_list_type_unresolved():
 
 
 def test_list_type_simple_type():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -506,11 +536,11 @@ def test_list_type_simple_type():
             </xsd:complexType>
           </xsd:element>
         </schema>
-    """)
+    """
+    )
 
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element(
-        '{http://tests.python-zeep.org/}foo')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
     value = xsd_element(arg=[1, 2, 3, 4, 5])
 
     node = render_node(xsd_element, value)
@@ -525,7 +555,8 @@ def test_list_type_simple_type():
 
 
 def test_union_type():
-    node = load_xml("""
+    node = load_xml(
+        """
         <schema xmlns="http://www.w3.org/2001/XMLSchema"
                 xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                 xmlns:tns="http://tests.python-zeep.org/"
@@ -548,15 +579,17 @@ def test_union_type():
             </xsd:complexType>
           </xsd:element>
         </schema>
-    """)
+    """
+    )
 
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}foo')
-    assert xsd_element(arg='hoi')
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}foo")
+    assert xsd_element(arg="hoi")
 
 
 def test_simple_type_restriction():
-    node = load_xml("""
+    node = load_xml(
+        """
         <xsd:schema
             xmlns="http://tests.python-zeep.org/"
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -575,14 +608,16 @@ def test_simple_type_restriction():
             </xsd:restriction>
           </xsd:simpleType>
         </xsd:schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_type('{http://tests.python-zeep.org/}type_3')
-    assert xsd_element(100) == '100'
+    xsd_element = schema.get_type("{http://tests.python-zeep.org/}type_3")
+    assert xsd_element(100) == "100"
 
 
 def test_strip_spaces_from_qname():
-    node = load_xml("""
+    node = load_xml(
+        """
         <xsd:schema
             xmlns="http://tests.python-zeep.org/"
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -597,17 +632,20 @@ def test_strip_spaces_from_qname():
             </xsd:complexType>
           </xsd:element>
         </xsd:schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}STRIP_IT')
-    assert xsd_element('okay') == 'okay'
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}STRIP_IT")
+    assert xsd_element("okay") == "okay"
+
+    xsd_element = schema.get_element("{http://tests.python-zeep.org/}container")
+    elm = xsd_element(THIS_TOO="okay")
+    assert elm.THIS_TOO == "okay"
 
-    xsd_element = schema.get_element('{http://tests.python-zeep.org/}container')
-    elm = xsd_element(THIS_TOO='okay')
-    assert elm.THIS_TOO == 'okay'
 
 def test_referenced_elements_in_choice():
-    node = load_xml("""
+    node = load_xml(
+        """
         <xsd:schema
             xmlns:zeep="http://tests.python-zeep.org/"
             xmlns:xsd="http://www.w3.org/2001/XMLSchema"
@@ -629,10 +667,11 @@ def test_referenced_elements_in_choice():
           </xsd:element>
 
          </xsd:schema>
-    """)
+    """
+    )
     schema = parse_schema_node(node)
-    container_element = schema.get_element('{http://tests.python-zeep.org/}container')
+    container_element = schema.get_element("{http://tests.python-zeep.org/}container")
     for el_name, sub_element in container_element.type.elements:
-        assert el_name in ('el1', 'el2', 'el3')
+        assert el_name in ("el1", "el2", "el3")
         assert sub_element.min_occurs == 0
         assert sub_element.is_optional == True
